package sgc.portal.ei.ei0103.persistence;

import org.apache.ibatis.annotations.Mapper;
import sgc.portal.base.util.EasyHashMap;
import sgc.portal.ei.ei0103.dto.EI01030001USearch;
import sgc.portal.ei.ei0103.model.EI01030001U;

import java.util.List;

@Mapper
public interface EI01030001UMapper {
	
	/*
     * SEARCH LIST
     */
    List<EasyHashMap<String, Object>> getList(EI01030001USearch search);
    
    /*
     * UPDATE
     */
    int update1(EI01030001U eI01030001U);
    
    int update2(EI01030001U eI01030001U);
    
    int update3(EI01030001U eI01030001U);
    
    int update4(EI01030001U eI01030001U);
    
    int update5(EI01030001U eI01030001U);
    
    int update6(EI01030001U eI01030001U);
    
    int update7(EI01030001U eI01030001U);
    
    int update8(EI01030001U eI01030001U);
    
    int update9(EI01030001U eI01030001U);
    
    
    int insertOrUpdate1(EI01030001U eI01030001U);
    
    int insertOrUpdate2(EI01030001U eI01030001U);
    
    int insertOrUpdate3(EI01030001U eI01030001U);
    
    int insertOrUpdate4(EI01030001U eI01030001U);
    
    int insertOrUpdate5(EI01030001U eI01030001U);
    
    int insertOrUpdate6(EI01030001U eI01030001U);
    
    int insertOrUpdate7(EI01030001U eI01030001U);
    
    int insertOrUpdate8(EI01030001U eI01030001U);
    
    int insertOrUpdate9(EI01030001U eI01030001U);
    
}
